![](docs/images/sauruspark.gif)

# Automonisaur: Core Libraries

**[install](#install)** | **[build](#build)** | **[unittest in docker](#unittest-in-docker')** | 
**[unittest locally](#unittest-locally)** | **[codecov](https://codecov.io/gh/TheShellLand/automon-core)**

[![codecov](https://codecov.io/gh/TheShellLand/automon-core/branch/master/graph/badge.svg)](https://codecov.io/gh/TheShellLand/automon-core) [![CI](https://github.com/TheShellLand/automon-core/workflows/CI/badge.svg?branch=master)](https://github.com/TheShellLand/automon-core/actions)

#### install
```shell script
./install.sh
```

#### build
```shell script
./build.sh
```

#### unittest in docker
```shell script
./test.sh
```

#### unittest locally
```shell script
./unittests.sh
```
